@@ -15,9 +15,9 @@
 from __future__ import unicode_literals
 
 from caniusepython3 import dependencies
+from caniusepython3.test import mock, unittest
 
 import io
-import unittest
 
 
 class GraphResolutionTests(unittest.TestCase):
@@ -39,10 +39,21 @@ class GraphResolutionTests(unittest.TestCase):
                          dependencies.reasons_to_paths(reasons))
 
 
+class BlockingDependenciesTests(unittest.TestCase):
+
+    @mock.patch('caniusepython3.dependencies.dependencies')
+    def test_recursion(self, dependencies_mock):
+        deps = {'a': ['b'], 'b': ['a']}
+        dependencies_mock.side_effect = lambda name: deps[name]
+        got = dependencies.blocking_dependencies(['a'], {})
+        self.assertEqual(frozenset(), got)
+
+
+
 class NetworkTests(unittest.TestCase):
 
     def test_blocking_dependencies(self):
-        got = dependencies.blocking_dependencies(['pastescript'], {'paste'})
+        got = dependencies.blocking_dependencies(['pastescript'], {'paste': ''})
         want = frozenset([('pastedeploy', 'pastescript')])
         self.assertEqual(frozenset(got), want)
 
@@ -52,14 +63,17 @@ class NetworkTests(unittest.TestCase):
 
     def test_dependencies_no_project(self):
         got = dependencies.dependencies('sdflksjdfsadfsadfad')
-        if hasattr(self, 'assertIsNone'):
-            self.assertIsNone(got)
-        else:
-            self.assertTrue(got is None)
+        self.assertIsNone(got)
 
     def test_blocking_dependencies_no_project(self):
         got = dependencies.blocking_dependencies(['asdfsadfdsfsdffdfadf'], {})
         self.assertEqual(got, frozenset())
 
+    def test_top_level_project_normalization(self):
+        py3 = {'wsgi_intercept': ''}
+        abnormal_name = 'WSGI-intercept'  # Note dash instead of underscore.
+        got = dependencies.blocking_dependencies([abnormal_name], py3)
+        self.assertEqual(got, frozenset())
+
 if __name__ == '__main__':
     unittest.main()
